part of "./side_nav.dart";

class _SideBar extends StatefulWidget {
  /// 导航Id
  final int navId;

  /// 菜单项集合
  final List<VSideNavMenuItem> items;

  final VSideNavViewController controller;

  const _SideBar({
    required this.controller,
    required this.navId,
    required this.items,
  });

  @override
  State<StatefulWidget> createState() => _SideBarState();
}

class _SideBarState extends State<_SideBar> {
  @override
  Widget build(BuildContext context) {
    return Scrollbar(
      thumbVisibility: true,
      child: ListView(
        padding: const EdgeInsets.symmetric(horizontal: 14, vertical: 12),
        children: _buildChildren(context),
      ),
    );
  }

  List<Widget> _buildChildren(BuildContext context) {
    final children = <Widget>[];

    final hasAnyIcon = widget.items.any((e) => e.icon != null);

    final divider = Divider(
      thickness: 1,
      color: Colors.grey.shade400,
      indent: hasAnyIcon ? 32 : 0,
    );

    final count = widget.items.length;
    for (var i = 0; i < count; i++) {
      final item = widget.items[i];

      if (item.shouldRearrage) {
        children.add(const SizedBox(height: 12));
      } else if (i > 0) {
        children.add(divider);
      }

      final cell = _buildMenuCell(item);
      children.add(cell);
    }

    return children;
  }

  Widget _buildMenuCell(VSideNavMenuItem item) {
    // final hasSection =
    //     item.routeName != null && _currentAnchor == item.routeName;

    return VListFormCell(
      leadingIcon: item.icon,
      leadingIconWidth: 32,
      label: item.title,
      onTap: () {
        if (item.onTap != null) {
          item.onTap!.call();
        } else if (item.route != null) {
          Get.offAllNamed(item.route!.name, id: widget.navId);
        }
      },
    );
  }
}
