import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';

import '../../../../components/alert_dialog.dart';

/// 小弹窗输入
class VDialogBloodPressure extends StatelessWidget {
  /// 标题
  final String? title;

  /// 描述
  final String? description;

  /// 输入占位符
  final String? placeholder;

  /// 初始值
  final List<String>? initialValue;

  const VDialogBloodPressure({
    super.key,
    this.title,
    this.description,
    this.placeholder,
    this.initialValue,
  });

  Future<String?> show<String>() => VAlertDialog.showDialog<String>(this);

  @override
  Widget build(BuildContext context) {
    final controller1 = TextEditingController(text: initialValue?.first);
    final controller2 = TextEditingController(text: initialValue?.last);
    return VAlertDialog(
      title: title,
      width: 440,
      contentPadding: const EdgeInsets.symmetric(vertical: 12, horizontal: 24),
      content: _buildContent(context, controller1, controller2),
      showCancel: true,
      onConfirm: () {
        Get.back(result: json.encode([controller1.text, controller2.text]));
      },
    );
  }

  Widget _buildContent(
    BuildContext context,
    TextEditingController controller1,
    TextEditingController controller2,
  ) {
    final children = <Widget>[];
    if (description != null) {
      children.add(
        Padding(
          padding: const EdgeInsets.symmetric(horizontal: 4),
          child: Text(
            description!,
            style: const TextStyle(color: Colors.black87, fontSize: 18),
          ),
        ),
      );
      children.add(const SizedBox(height: 8));
    } else {
      children.add(const SizedBox(height: 12));
    }
    children.add(_buildInputWidget(context, controller1, controller2));
    return SingleChildScrollView(
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: children,
      ),
    );
  }

  Widget _buildInputWidget(
    BuildContext context,
    TextEditingController controller1,
    TextEditingController controller2,
  ) {
    const fontSize = 20.0;
    const height = 56.0;
    return Row(
      children: [
        _buildItem(context, controller1, '高压'),
        const Text(
          '/',
          style: TextStyle(fontSize: fontSize),
        ),
        _buildItem(context, controller2, '低压'),
      ],
    );
  }

  Widget _buildItem(
    BuildContext context,
    TextEditingController controller,
    String hintText,
  ) {
    const fontSize = 20.0;
    const height = 56.0;
    return Expanded(
      child: SizedBox(
        height: height,
        child: TextField(
          controller: controller,
          readOnly: false,
          autofocus: true,
          keyboardType: const TextInputType.numberWithOptions(
              decimal: true), // 允许输入数字和小数点
          inputFormatters: [
            FilteringTextInputFormatter.allow(
              RegExp(r'^\d+\.?\d{0,2}'),
            ), // 只允许输入数字和小数点,俩位小数
          ],
          style: const TextStyle(fontSize: fontSize),
          decoration: InputDecoration(
            border: const UnderlineInputBorder(
              borderRadius: BorderRadius.zero,
              borderSide: BorderSide(),
            ),
            enabledBorder: const UnderlineInputBorder(
              borderRadius: BorderRadius.zero,
              borderSide: BorderSide(
                color: Colors.black54,
              ),
            ),
            focusedBorder: UnderlineInputBorder(
              borderRadius: BorderRadius.zero,
              borderSide: BorderSide(
                color: Theme.of(context).primaryColor.withOpacity(.4),
              ),
            ),
            filled: true,
            fillColor: Colors.white,
            contentPadding: const EdgeInsets.symmetric(
              vertical: (height - fontSize * 1.2) / 2,
              horizontal: 8,
            ),
            hintStyle: const TextStyle(fontSize: fontSize),
            labelStyle: const TextStyle(fontSize: fontSize),
            hintText: hintText,
            isCollapsed: true,
          ),
          onSubmitted: (value) {
            print(value);
            Get.back(result: value);
          },
        ),
      ),
    );
  }
}
