// ignore_for_file: unused_element

import 'package:fis_jsonrpc/rpc.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:vnoteapp/managers/contract/index.dart';

import '../controller.dart';

/// 人群分类卡片
class CrowdLabelsCard extends GetView<PatientDetailController> {
  const CrowdLabelsCard({super.key});

  @override
  Widget build(BuildContext context) {
    return _TitleInfoCardContainer(
      title: "人群分类",
      titleIcon: const Icon(Icons.people, color: Colors.white),
      child: Container(
        alignment: Alignment.topLeft,
        padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 8),
        child: Obx(
          () => Wrap(
            spacing: 16,
            runSpacing: 12,
            children: (controller.state.labelNames ?? [])
                .map((e) => _CrowdLabelTag(name: e))
                .toList(),
          ),
        ),
      ),
    );
  }
}

/// 随访提醒卡片
class FollowupTipsCard extends GetView<PatientDetailController> {
  const FollowupTipsCard({super.key});

  @override
  Widget build(BuildContext context) {
    final state = controller.state;
    final ContractUtils contractUtils = ContractUtils();

    return _TitleInfoCardContainer(
      title: "签约信息",
      titleIcon: const Icon(Icons.tips_and_updates, color: Colors.white),
      // titleBgColor: Colors.yellow.shade900,
      child: Padding(
        padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 8),
        child: Column(
          children: [
            _buildItem(
              "签约状态",
              contractUtils.contractStateTransition(state.contractState),
            ),
            _buildItem(
                "签约医生",
                state.contractState != ContractStateEnum.Signed
                    ? ""
                    : state.contractedDoctorName),
            // _buildItem("签约日期", '2023-10-12'),
          ],
        ),
      ),
    );
  }

  Widget _buildItem(String label, String content) {
    return SizedBox(
      height: 30,
      child: Row(
        children: [
          Text(
            label,
            style: const TextStyle(color: Colors.grey, fontSize: 18),
          ),
          const SizedBox(width: 12),
          Text(
            content,
            style: const TextStyle(color: Colors.black, fontSize: 18),
          ),
        ],
      ),
    );
  }
}

class _TitleInfoCardContainer extends StatelessWidget {
  final Widget child;
  final String title;
  final Widget? titleIcon;
  final Color? titleBgColor;

  const _TitleInfoCardContainer({
    required this.child,
    required this.title,
    this.titleIcon,
    this.titleBgColor,
  });

  @override
  Widget build(BuildContext context) {
    Widget titleWidget = Text(
      title,
      style: const TextStyle(color: Colors.white, fontSize: 20),
    );
    if (titleIcon != null) {
      titleWidget = Row(
        mainAxisSize: MainAxisSize.min,
        children: [
          titleIcon!,
          const SizedBox(width: 8),
          titleWidget,
        ],
      );
    }
    return Container(
      alignment: Alignment.topLeft,
      decoration: BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.circular(8),
      ),
      child: Column(
        children: [
          Container(
            alignment: Alignment.centerLeft,
            padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 8),
            decoration: BoxDecoration(
              gradient: LinearGradient(
                colors: [
                  // Color.fromRGBO(59, 188, 255, 1),
                  // Color.fromRGBO(44, 120, 229, 1),
                  Theme.of(context).primaryColor,
                  Theme.of(context).primaryColor.withOpacity(.6),
                ],
                begin: Alignment.topLeft,
                end: Alignment.bottomRight,
              ),
              // color: titleBgColor ?? Theme.of(context).primaryColor,
              borderRadius: const BorderRadius.only(
                topLeft: Radius.circular(8),
                topRight: Radius.circular(8),
              ),
            ),
            child: titleWidget,
          ),
          Container(
            padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 8),
            child: child,
          ),
        ],
      ),
    );
  }
}

class _CrowdLabelTag extends StatelessWidget {
  final String name;
  final String? code;
  final ValueChanged<String?>? onTap;
  final Color? backgroundColor;

  const _CrowdLabelTag({
    required this.name,
    this.onTap,
    this.backgroundColor,
    this.code,
  });

  @override
  Widget build(BuildContext context) {
    final color =
        backgroundColor ?? Theme.of(context).primaryColor.withOpacity(.6);
    return Material(
      child: InkWell(
        borderRadius: BorderRadius.circular(8),
        onTap: onTap != null ? () => onTap!.call(code) : null,
        child: IntrinsicWidth(
          child: ConstrainedBox(
            constraints: const BoxConstraints(minWidth: 100),
            child: Container(
              alignment: Alignment.center,
              height: 32,
              decoration: BoxDecoration(
                color: color,
                borderRadius: BorderRadius.circular(8),
              ),
              child: Text(
                name,
                style: const TextStyle(color: Colors.white, fontSize: 14),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
